@@ -1,6 +1,7 @@
 import os
 import logging
-from secret_extractor import SecretExtractor
+
+from SecretManagerEnvInjector.secret_extractor import SecretExtractor
 
 logger = logging.getLogger()
 
@@ -17,13 +18,13 @@ def inject(secret_arn: str, region: str = 'us-east-1', custom_secret_name:str =
                 if secret:
                     os.environ[str(secret_name)] = secret
             except Exception as ex:
-                logger.error('Exception: ', ex)
+                logger.error('Exception: {}'.format(ex))
             return func(*args, **kwargs)
         return wrap
     return inner_wrap
 
 if __name__ == '__main__':
-    @inject('arn:aws:secretsmanager:us-east-1:878616621923:secret:bogus-dj3g0R', 'us-east-1', 'my-secret')
+    @inject('arn:aws:secretsmanager:us-xxxx-1:xxxxxxxxxxx:secret:bogus-dj3g0R', 'us-east-1', 'my-secret')
     def test():
         print("hello")
     test()
\ No newline at end of file
